You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@camel.apache.org by lb...@apache.org on 2016/07/22 08:02:04 UTC

camel git commit: Fix spelling, component pom

Repository: camel
Updated Branches:
  refs/heads/master 1c148887c -> 2bbc1368b


Fix spelling, component pom


Project: http://git-wip-us.apache.org/repos/asf/camel/repo
Commit: http://git-wip-us.apache.org/repos/asf/camel/commit/2bbc1368
Tree: http://git-wip-us.apache.org/repos/asf/camel/tree/2bbc1368
Diff: http://git-wip-us.apache.org/repos/asf/camel/diff/2bbc1368

Branch: refs/heads/master
Commit: 2bbc1368b233f630f6acbf6d6c8d52ec5f1d1772
Parents: 1c14888
Author: lburgazzoli <lb...@gmail.com>
Authored: Fri Jul 22 10:01:21 2016 +0200
Committer: lburgazzoli <lb...@gmail.com>
Committed: Fri Jul 22 10:01:21 2016 +0200

----------------------------------------------------------------------
 .../engine/ChronicleEngineComponent.java        |  8 +-
 .../engine/ChronicleEngineConsumer.java         |  4 +-
 .../engine/ChronicleEngineEndpoint.java         | 96 ++++++++++++++++++++
 .../engine/ChronicleEngineEnpoint.java          | 96 --------------------
 .../engine/ChronicleEngineProducer.java         |  4 +-
 components/pom.xml                              |  1 +
 6 files changed, 105 insertions(+), 104 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/camel/blob/2bbc1368/components/camel-chronicle/src/main/java/org/apache/camel/component/chronicle/engine/ChronicleEngineComponent.java
----------------------------------------------------------------------
diff --git a/components/camel-chronicle/src/main/java/org/apache/camel/component/chronicle/engine/ChronicleEngineConsumer.java b/components/camel-chronicle/src/main/java/org/apache/camel/component/chronicle/engine/ChronicleEngineConsumer.java
index 4cf79d4..52bd453 100644
--- a/components/camel-chronicle/src/main/java/org/apache/camel/component/chronicle/engine/ChronicleEngineConsumer.java
+++ b/components/camel-chronicle/src/main/java/org/apache/camel/component/chronicle/engine/ChronicleEngineConsumer.java
@@ -38,7 +38,7 @@ public class ChronicleEngineConsumer extends DefaultConsumer {
     private final String path;
     private AssetTree client;
 
-    public ChronicleEngineConsumer(ChronicleEngineEnpoint endpoint, Processor processor) {
+    public ChronicleEngineConsumer(ChronicleEngineEndpoint endpoint, Processor processor) {
         super(endpoint, processor);
 
         this.path = endpoint.getPath();
@@ -50,7 +50,7 @@ public class ChronicleEngineConsumer extends DefaultConsumer {
             throw new IllegalStateException("AssetTree already configured");
         }
 
-        ChronicleEngineEnpoint endpoint = (ChronicleEngineEnpoint)getEndpoint();
+        ChronicleEngineEndpoint endpoint = (ChronicleEngineEndpoint)getEndpoint();
         ChronicleEngineConfiguration conf = endpoint.getConfiguration();
         client = endpoint.createRemoteAssetTree();
 

http://git-wip-us.apache.org/repos/asf/camel/blob/2bbc1368/components/camel-chronicle/src/main/java/org/apache/camel/component/chronicle/engine/ChronicleEngineEndpoint.java
----------------------------------------------------------------------
diff --git a/components/camel-chronicle/src/main/java/org/apache/camel/component/chronicle/engine/ChronicleEngineEndpoint.java b/components/camel-chronicle/src/main/java/org/apache/camel/component/chronicle/engine/ChronicleEngineEndpoint.java
new file mode 100644
index 0000000..8939a3c
--- /dev/null
+++ b/components/camel-chronicle/src/main/java/org/apache/camel/component/chronicle/engine/ChronicleEngineEndpoint.java
@@ -0,0 +1,96 @@
+/**
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+package org.apache.camel.component.chronicle.engine;
+
+import net.openhft.chronicle.engine.api.tree.AssetTree;
+import net.openhft.chronicle.engine.tree.VanillaAssetTree;
+import org.apache.camel.Consumer;
+import org.apache.camel.Processor;
+import org.apache.camel.Producer;
+import org.apache.camel.impl.DefaultEndpoint;
+import org.apache.camel.spi.Metadata;
+import org.apache.camel.spi.UriEndpoint;
+import org.apache.camel.spi.UriPath;
+import org.apache.camel.util.ObjectHelper;
+
+
+@UriEndpoint(scheme = "chronicle-engine", title = "Chronicle Engine", syntax = "chronicle-engine:addresses/path", consumerClass = ChronicleEngineConsumer.class, label = "Chronicle")
+public class ChronicleEngineEndpoint extends DefaultEndpoint {
+    private final ChronicleEngineConfiguration configuration;
+
+    @UriPath(description = "engine path")
+    @Metadata(required = "true")
+    private final String path;
+
+    public ChronicleEngineEndpoint(String uri, ChronicleEngineComponent component, ChronicleEngineConfiguration configuration) throws Exception {
+        super(uri, component);
+
+        ObjectHelper.notNull(configuration.getCamelContext(), "camelContext");
+        ObjectHelper.notNull(configuration.getAddresses(), "addresses");
+        ObjectHelper.notNull(configuration.getPath(), "path");
+        ObjectHelper.notNull(configuration.getWireType(), "wireType");
+
+        this.configuration = configuration;
+        this.path = configuration.getPath();
+    }
+
+    @Override
+    public boolean isSingleton() {
+        return true;
+    }
+
+    @Override
+    public Producer createProducer() throws Exception {
+        return new ChronicleEngineProducer(this);
+    }
+
+    @Override
+    public Consumer createConsumer(Processor processor) throws Exception {
+        return new ChronicleEngineConsumer(this, processor);
+    }
+
+    @Override
+    protected void doStart() throws Exception {
+    }
+
+    @Override
+    protected void doStop() throws Exception {
+    }
+
+    // ****************************
+    // Helpers
+    // ****************************
+
+    protected ChronicleEngineConfiguration getConfiguration() {
+        return configuration;
+    }
+
+    protected String getPath() {
+        return this.path;
+    }
+
+    protected String getUri() {
+        return configuration.isPersistent()
+            ? configuration.getPath()
+            : configuration.getPath() + "?dontPersist=true";
+    }
+
+    protected AssetTree createRemoteAssetTree() {
+        return new VanillaAssetTree()
+            .forRemoteAccess(configuration.getAddresses(), configuration.getWireType());
+    }
+}

http://git-wip-us.apache.org/repos/asf/camel/blob/2bbc1368/components/camel-chronicle/src/main/java/org/apache/camel/component/chronicle/engine/ChronicleEngineEnpoint.java
----------------------------------------------------------------------
diff --git a/components/camel-chronicle/src/main/java/org/apache/camel/component/chronicle/engine/ChronicleEngineEnpoint.java b/components/camel-chronicle/src/main/java/org/apache/camel/component/chronicle/engine/ChronicleEngineEnpoint.java
deleted file mode 100644
index 04180c8..0000000
--- a/components/camel-chronicle/src/main/java/org/apache/camel/component/chronicle/engine/ChronicleEngineEnpoint.java
+++ /dev/null
@@ -1,96 +0,0 @@
-/**
- * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements.  See the NOTICE file distributed with
- * this work for additional information regarding copyright ownership.
- * The ASF licenses this file to You under the Apache License, Version 2.0
- * (the "License"); you may not use this file except in compliance with
- * the License.  You may obtain a copy of the License at
- *
- *      http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- */
-package org.apache.camel.component.chronicle.engine;
-
-import net.openhft.chronicle.engine.api.tree.AssetTree;
-import net.openhft.chronicle.engine.tree.VanillaAssetTree;
-import org.apache.camel.Consumer;
-import org.apache.camel.Processor;
-import org.apache.camel.Producer;
-import org.apache.camel.impl.DefaultEndpoint;
-import org.apache.camel.spi.Metadata;
-import org.apache.camel.spi.UriEndpoint;
-import org.apache.camel.spi.UriPath;
-import org.apache.camel.util.ObjectHelper;
-
-
-@UriEndpoint(scheme = "chronicle-engine", title = "Chronicle Engine", syntax = "chronicle-engine:addresses/path", consumerClass = ChronicleEngineConsumer.class, label = "Chronicle")
-public class ChronicleEngineEnpoint extends DefaultEndpoint {
-    private final ChronicleEngineConfiguration configuration;
-
-    @UriPath(description = "engine path")
-    @Metadata(required = "true")
-    private final String path;
-
-    public ChronicleEngineEnpoint(String uri, ChronicleEngineComponent component, ChronicleEngineConfiguration configuration) throws Exception {
-        super(uri, component);
-
-        ObjectHelper.notNull(configuration.getCamelContext(), "camelContext");
-        ObjectHelper.notNull(configuration.getAddresses(), "addresses");
-        ObjectHelper.notNull(configuration.getPath(), "path");
-        ObjectHelper.notNull(configuration.getWireType(), "wireType");
-
-        this.configuration = configuration;
-        this.path = configuration.getPath();
-    }
-
-    @Override
-    public boolean isSingleton() {
-        return true;
-    }
-
-    @Override
-    public Producer createProducer() throws Exception {
-        return new ChronicleEngineProducer(this);
-    }
-
-    @Override
-    public Consumer createConsumer(Processor processor) throws Exception {
-        return new ChronicleEngineConsumer(this, processor);
-    }
-
-    @Override
-    protected void doStart() throws Exception {
-    }
-
-    @Override
-    protected void doStop() throws Exception {
-    }
-
-    // ****************************
-    // Helpers
-    // ****************************
-
-    protected ChronicleEngineConfiguration getConfiguration() {
-        return configuration;
-    }
-
-    protected String getPath() {
-        return this.path;
-    }
-
-    protected String getUri() {
-        return configuration.isPersistent()
-            ? configuration.getPath()
-            : configuration.getPath() + "?dontPersist=true";
-    }
-
-    protected AssetTree createRemoteAssetTree() {
-        return new VanillaAssetTree()
-            .forRemoteAccess(configuration.getAddresses(), configuration.getWireType());
-    }
-}

http://git-wip-us.apache.org/repos/asf/camel/blob/2bbc1368/components/camel-chronicle/src/main/java/org/apache/camel/component/chronicle/engine/ChronicleEngineProducer.java
----------------------------------------------------------------------
diff --git a/components/camel-chronicle/src/main/java/org/apache/camel/component/chronicle/engine/ChronicleEngineProducer.java b/components/camel-chronicle/src/main/java/org/apache/camel/component/chronicle/engine/ChronicleEngineProducer.java
index 4473031..9d41799 100644
--- a/components/camel-chronicle/src/main/java/org/apache/camel/component/chronicle/engine/ChronicleEngineProducer.java
+++ b/components/camel-chronicle/src/main/java/org/apache/camel/component/chronicle/engine/ChronicleEngineProducer.java
@@ -40,7 +40,7 @@ public class ChronicleEngineProducer extends HeaderSelectorProducer {
     private WeakRef<QueueView<Object, Object>> queueView;
     private AssetTree client;
 
-    public ChronicleEngineProducer(ChronicleEngineEnpoint endpoint) {
+    public ChronicleEngineProducer(ChronicleEngineEndpoint endpoint) {
         super(endpoint, ChronicleEngineConstants.ACTION, endpoint.getConfiguration().getAction());
 
         this.uri = endpoint.getUri();
@@ -62,7 +62,7 @@ public class ChronicleEngineProducer extends HeaderSelectorProducer {
             throw new IllegalStateException("AssetTree already configured");
         }
 
-        client = ((ChronicleEngineEnpoint)getEndpoint()).createRemoteAssetTree();
+        client = ((ChronicleEngineEndpoint)getEndpoint()).createRemoteAssetTree();
     }
 
     @Override

http://git-wip-us.apache.org/repos/asf/camel/blob/2bbc1368/components/pom.xml
----------------------------------------------------------------------
diff --git a/components/pom.xml b/components/pom.xml
index 6882f95..a1b023d 100644
--- a/components/pom.xml
+++ b/components/pom.xml
@@ -97,6 +97,7 @@
     <module>camel-cassandraql</module>
     <module>camel-castor</module>
     <module>camel-cdi</module>
+    <module>camel-chronicle</module>
     <module>camel-chunk</module>
     <module>camel-cm-sms</module>
     <module>camel-cmis</module>
diff --git a/components/camel-chronicle/src/main/java/org/apache/camel/component/chronicle/engine/ChronicleEngineComponent.java b/components/camel-chronicle/src/main/java/org/apache/camel/component/chronicle/engine/ChronicleEngineComponent.java
index bbc6975..06d7d7d 100644
--- a/components/camel-chronicle/src/main/java/org/apache/camel/component/chronicle/engine/ChronicleEngineComponent.java
+++ b/components/camel-chronicle/src/main/java/org/apache/camel/component/chronicle/engine/ChronicleEngineComponent.java
@@ -24,16 +24,16 @@ import org.apache.camel.impl.UriEndpointComponent;
 import org.apache.camel.util.ObjectHelper;
 
 /**
  * Represents the component that manages {@link ChronicleEngineEnpoint}.
  */
 public class ChronicleEngineComponent extends UriEndpointComponent {
     
     public ChronicleEngineComponent() {
-        super(ChronicleEngineEnpoint.class);
+        super(ChronicleEngineEndpoint.class);
     }
 
     public ChronicleEngineComponent(CamelContext context) {
-        super(context, ChronicleEngineEnpoint.class);
+        super(context, ChronicleEngineEndpoint.class);
     }
 
     @Override
@@ -45,6 +45,6 @@ public class ChronicleEngineComponent extends UriEndpointComponent {
 
         setProperties(configuration, parameters);
 
-        return new ChronicleEngineEnpoint(uri, this, configuration);
+        return new ChronicleEngineEndpoint(uri, this, configuration);
     }
 }

http://git-wip-us.apache.org/repos/asf/camel/blob/2bbc1368/components/camel-chronicle/src/main/java/org/apache/camel/component/chronicle/engine/ChronicleEngineConsumer.java
----------------------------------------------------------------------
@@ -24,16 +24,16 @@ import org.apache.camel.impl.UriEndpointComponent;
 
 /**
- * Represents the component that manages {@link ChronicleEngineEnpoint}.
+ * Represents the component that manages {@link ChronicleEngineEndpoint}.
  */
 public class ChronicleEngineComponent extends UriEndpointComponent {